#include <stdio.h>
#include <assert.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>

class Reader
{
protected:
	FILE *f;
	int putBackCh;
public:
	Reader(FILE *F) : putBackCh(-1), f(F) { assert(f); }
	~Reader() { if (f) fclose(f); }
	void PutBack(char ch) { assert(putBackCh < 0); putBackCh = ch; }
	int GetCh() {
		if (putBackCh >= 0) { int ch = putBackCh; putBackCh = -1; return ch; }
		else { /*printf("!");*/ return fgetc(f); }}
	bool SkipWs(int& ch) { bool any = false; for ( ; ; ) {
		ch = GetCh();
//printf("<%d; %d>", any, ch);
		if (ch == EOF) return any;
		else if (! (isspace(ch) || ch == '\xa' || ch == '\xd')) { PutBack(ch); return any; }
		else any = true; } }
	bool SkipSpaces(int& ch) { bool any = false; for ( ; ; ) {
		ch = GetCh();
		if (ch == EOF) return any;
		else if (! (isspace(ch) && ch != '\xa' && ch != '\xd')) { PutBack(ch); return any; }
		else any = true; } }
	bool ReadInt(int& i, FILE *fRept, const int lineNo, const char *cesa);
	bool ReadString(char *dest, int maxChars, const char* extraStopChars); // stop at space or extraStopChars
	bool AtEof() { int ch = GetCh(); if (ch < 0) return true; else { PutBack(ch); return false; }}
	bool AtEol() { int ch = GetCh(); bool b = (ch == '\xa' || ch == '\xd');
		if (ch >= 0) PutBack(ch);
		return b; }
	bool ReadLn() {
		int ch = GetCh(); if (ch < 0) return false;
		if (ch == '\xa') return true;
		if (ch == '\xd') {
			ch = GetCh();
			if (ch >= 0 && ch != '\xa') PutBack(ch);
			return true; }
		PutBack(ch); return false; }
	void ReadLnA() { bool ok = ReadLn(); assert(ok); }
};

bool Reader::ReadString(char *dest, int maxChars, const char* extraStopChars)
{
	int nRead = 0;
	for ( ; ; )
	{
		int ch = GetCh();
		if (ch < 0 || isspace(ch) || strchr(extraStopChars, ch)) { dest[nRead] = 0; if (ch > 0) PutBack(ch); return true; }
		if (nRead == maxChars) { dest[nRead] = 0; return false; }
		dest[nRead++] = char(ch);
	}
}

bool Reader::ReadInt(int& i, FILE *fRept, const int lineNo, const char *cesa)
{
	i = 0;
	int nDigits = 0;
	bool negative = false;
	{int ch = GetCh(); if (ch == '-') negative = true; else PutBack(ch);}
	for ( ; ; )
	{
		int ch = GetCh();
		if (ch < 0) { if (nDigits <= 0) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Pricakoval bi stevilo, nasel sem EOF.\n", cesa, lineNo); return false; }
			else return true; }
		if (ch < int('0') || ch > int('9')) { PutBack(ch);
			if (nDigits <= 0) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Pricakoval bi stevilo, nasel sem znak 0x%02x.\n", cesa, lineNo, int(ch)); return false; }
			else return true; }
		// 2^31 = 2147483648
		//printf("i = %d\n", i);
		if (i > 214748364) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Stevilo je preveliko (overflow).\n", cesa, lineNo); return false; }
		if (i < -214748364) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Stevilo je premajhno (underflow).\n", cesa, lineNo); return false; }
		/*
		int j = 2147483647 - i, d = int(ch - '0');
		//printf("i = %d, j = %d, d = %d\n", i, j, d);
		if (j < d) { fprintf(fRept, "%d. stevilo je preveliko (overflow).\n", katero); return false; }
		*/
		int d = int(ch - '0');
		if (i == 214748364 && d > 7) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Stevilo je preveliko (overflow).\n", cesa, lineNo); return false; }
		if (i == -214748364 && d > 8) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Stevilo je premajhno (underflow).\n", cesa, lineNo); return false; }
		i *= 10;
		if (negative) i -= d; else i += d;
		nDigits++;
	}
}


// > 1 --> error
// <= 0 --> OK (# points = return value + 10)
//
bool Test(const char* fnIn, const char* fnOut, const char* fnRept, const char* fnOrigOut, int& nPoints)
{
	nPoints = 0;
	// Read the input file.
	FILE *fIn = fopen(fnIn, "rt"); assert(fIn);
	enum { MaxN = 100, MaxLen = 100 };
	int n, lens[MaxN]; 
	{int ok = fscanf(fIn, "%d", &n); assert(ok == 1); assert(0 < n && n <= MaxN);
	for (int i = 0; i < n; i++) { ok = fscanf(fIn, "%d", &(lens[i])); assert(ok == 1); assert(0 < lens[i] && lens[i] <= MaxLen); }}
	fclose(fIn);
	// Read the best solution from the original output file.
	int bestSol = -1;
	FILE *fOrigOut = fopen(fnOrigOut, "rt"); assert(fOrigOut);
	int ok = fscanf(fOrigOut, "%d", &bestSol); assert(ok == 1); assert(0 < bestSol && bestSol <= MaxLen);
	fclose(fOrigOut);
	// Read the output file.
	FILE *fRept = fopen(fnRept, "wt"); assert(fRept);
	FILE *fOut = fopen(fnOut, "rb"); if (! fOut) { fprintf(fRept, "Ne morem odpreti izhodne datoteke \"%s\".\n", fnOut ? fnOut : "\0"); fclose(fRept); return false; }
	Reader reader(fOut);
	int sol = -1, where[MaxN], dummy;
	reader.SkipSpaces(dummy); 
	if (! reader.ReadInt(sol, fRept, 1, "dolzine najkrajsega trajekta")) { fclose(fRept); return false; }
	reader.SkipSpaces(dummy);
	if (! reader.AtEol()) { fprintf(fRept, "Napaka v izhodni datoteki: v 1. vrstici so za dolzino najkrajsega trajekta se neki drugi znaki.\n"); fclose(fRept); return false; }
	reader.ReadLn();
	int total1 = 0, total2 = 0, total3 = 0;
	for (int i = 0; i < n; i++)
	{
		reader.SkipSpaces(dummy); 
		char buf[100]; sprintf(buf, "pasu %d. tovornjaka", i + 1);
		if (! reader.ReadInt(where[i], fRept, i + 2, buf)) { fclose(fRept); return false; }
		if (where[i] < 1 || where[i] > 3) { fprintf(fRept, "Pas %d. tovornjaka je %d (moral bi biti 1, 2 ali 3).\n", i + 1, where[i]); fclose(fRept); return false; }
		reader.SkipSpaces(dummy);
		if (! reader.AtEol()) { fprintf(fRept, "Napaka v izhodni datoteki: v %d. vrstici so za pasom %d. tovornjaka se neki drugi znaki.\n", i + 2, i + 1); fclose(fRept); return false; }
		reader.ReadLn();
		if (where[i] == 1) total1 += lens[i];
		if (where[i] == 2) total2 += lens[i];
		if (where[i] == 3) total3 += lens[i];
	}
	reader.SkipWs(dummy); if (! reader.AtEof()) { fprintf(fRept, "Napaka v izhodni datoteki: za podatki o pasovih vseh %d tovornjakov so se neki drugi znaki.\n", n); fclose(fRept); return false; }
	//fprintf(fRept, "%d | %d %d %d | ", sol, total1, total2, total3);
	//
	if (total1 > sol) { fprintf(fRept, "Izhodna datoteka pravi, da je dolzina trajekta %d, a na prvem pasu je skupna dolzina tovornjakov kar %d.\n", sol, total1); fclose(fRept); return false; }
	if (total2 > sol) { fprintf(fRept, "Izhodna datoteka pravi, da je dolzina trajekta %d, a na drugem pasu je skupna dolzina tovornjakov kar %d.\n", sol, total2); fclose(fRept); return false; }
	if (total3 > sol) { fprintf(fRept, "Izhodna datoteka pravi, da je dolzina trajekta %d, a na tretjem pasu je skupna dolzina tovornjakov kar %d.\n", sol, total3); fclose(fRept); return false; }
	if (total1 < sol && total2 < sol && total3 < sol) { 
		// Oh well, their loss.  We won't complain.
		//fprintf(fRept, "Izhodna datoteka pravi, da je dolzina trajekta %d, a na nobenem pasu skupna dolzina tovornjakov ni toliksna.\n", sol); fclose(fRept); return false; 
	}
	//
	nPoints = 10; 
	if (sol < bestSol) { fprintf(fRept, "Tvoja resitev je se boljsa od resitve komisije.  Ocitno so v resitvah komisije neke napake.\n"); fclose(fRept); return true; }
	if (sol == bestSol) { fprintf(fRept, "OK, nasel si najkrajsi mozni trajekt (%d/10 tock).\n", nPoints); fclose(fRept); return true; }
	nPoints = 10 - (sol - bestSol); if (nPoints < 1) nPoints = 1;
	fprintf(fRept, "OK, tvoja resitev je pravilna, vendar ni najboljsa mozna (%d/10 tock).\n", nPoints);
	fclose(fRept);
	return true;
}

int main(int argc, char** argv)
{
	assert(argc == 5);
	int nPoints = 0;
	bool ok = Test(argv[1], argv[2], argv[3], argv[4], nPoints);
	if (! ok) return -10; else return nPoints - 10;
}
